@@ -71,6 +71,7 @@ if ((! isset($SP_CONFIG)) && (! isset($configfile))) {
     exit();
 }
 
+$unencrypted_ok = true;
 require_once 'init_session.php';
 
 // suppress notice messages 
@@ -222,6 +223,11 @@ if (file_exists($MODULE.'/post_view.php')) {
     require $MODULE.'/post_view.php';
 }
 
+if (!$unencrypted_ok) {
+    $App->log('ERROR plaintext request while secure cookies enabled');
+    $App->view = 'require_https';
+    $App->setMsg('ERR_HTTPS');
+}
 /* Check template authorization */
 if ($App->getConfig('TEMPLATE_AUTHZ',true) &! $App->authz($App->view)) {
     // authzError
