@@ -554,7 +554,7 @@ class Application extends ApplicationConfig
         }
 
         $debug_vals   = preg_split('/,(\s+)?/',$this->DEBUG);
-        $debug_global = array_shift($debug_vals);
+        $debug_global = array_shift($debug_vals) || 0;
         foreach ($debug_vals as $debug_entry) {
             list($debug_module,$level) = explode(':',$debug_entry);
             if (($debug_module == $module) && ($level >= $threshold)) {
@@ -663,16 +663,7 @@ class Application extends ApplicationConfig
                 return $this->_check_array($value,$UNICODE);
             }
             else {
-                if ($UNICODE) {
-                    return stripslashes($value);
-                } else {
-                    return htmlentities(stripslashes($value),ENT_QUOTES);
-                }
-            }
-            if ($UNICODE) {
-                return stripslashes($this->_request[$attr]);
-            } else {
-                return htmlentities(stripslashes($this->_request[$attr]),ENT_QUOTES);
+                return htmlentities(stripslashes($value),ENT_QUOTES);
             }
         }
     }
@@ -695,12 +686,8 @@ class Application extends ApplicationConfig
             }
             return $ary;
         }
-        if ($UNICODE) {
-            return stripslashes($param);
-        }
-        else {
-            return htmlentities(stripslashes($param),ENT_QUOTES);
-        }
+
+        return htmlentities(stripslashes($param),ENT_QUOTES);
     }
 
 
@@ -714,7 +701,7 @@ class Application extends ApplicationConfig
      * @param string | array $params and values array
      */
     function redirect ($action,$plist=array(),$redirect_base='')
-   {
+    {
 
         $params = '';
 
@@ -895,12 +882,14 @@ class Application extends ApplicationConfig
         if ($language == 'DEFAULT_LANGUAGE') {
             $language = $default_language;
         }
+
         $this->lang = $language; 
 
         // skin localization
         $locale_txt = $this->tpl_root.'/'.$this->lang.'.txt';
         if (!is_readable($locale_txt)) {
             $locale_txt = $this->tpl_root.'/'.$default_language.'.txt';
+            $this->lang = $default_language;    // override unavailable language
         }
         $this->locale_txt = $locale_txt;
         // messages
