@@ -31,6 +31,12 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 require_once './model/User.php';
+require_once 'ctrl/CsrfToken.php';
+if (!CsrfToken::validate($App->getParam('csrf_token'))) {
+    $redata['MSG'] = 'INVALID_CSRF_TOKEN';
+    $App->redirect('userList', $redata);
+}
+
 
 $id = $App->getParam('id');
 
