@@ -38,7 +38,13 @@ require_once 'model/AppState.php';
 
 $authscript     = $App->getConfig('EXTERNAL_AUTH','/usr/sbin/benno_auth.d');
 
-$clientTimezone = $App->getParam('clientTimezone');
+if ($App->getConfig('DATEHEADER_TIMEZONE')) {
+    $clientTimezone = $App->getConfig('DATEHEADER_TIMEZONE');
+}
+else {
+    $clientTimezone = $App->getParam('clientTimezone');
+}
+
 $login          = $App->getParam('login',true);
 $userid         = $login['username']; // fetch masked parameter (DB access)
 $passwd         = $_REQUEST['login']['password']; // fetch PW raw
