@@ -96,13 +96,12 @@ class Backend implements Serializable
         $bennoId = QueryResult::getBennoId($sessionMailId);
         $App->log("Fetch mail from archive: $bennoId",3,'Backend');
 
-        $request_url  = $this->base_url.'/mail/';
         @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId;
         if ($scid)  $query_string .= '&scid='.$scid;
 
-        $maildata = $this->backend_request($request_url,$query_string);
+        $maildata = $this->backend_request('/mail',$query_string);
 
         $body   = $maildata['body'];
         $header = $maildata['header'];
@@ -132,14 +131,13 @@ class Backend implements Serializable
     {
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
-        $request_url  = $this->base_url.'/mail/';
         @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
                         '&format=headers';
         if ($scid)  $query_string .= '&scid='.$scid;
 
-        $header = $this->backend_request($request_url,$query_string,'headers');
+        $header = $this->backend_request('/mail',$query_string,'headers');
 
         return $header;
     }
@@ -156,7 +154,6 @@ class Backend implements Serializable
     {
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
-        $request_url  = $this->base_url.'/mail/';
         @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
@@ -167,7 +164,7 @@ class Backend implements Serializable
             $query_string .= '&skipUTF8Recode=true';
         }
 
-        $maildata = $this->backend_request($request_url,$query_string,'raw');
+        $maildata = $this->backend_request('/mail',$query_string,'raw');
 
         return $maildata;
     }
@@ -194,7 +191,7 @@ class Backend implements Serializable
 	    if($attachmentId != "")         
 	      $query_string .= '&attachmentId='.$attachmentId;
 
-        $file = $this->backend_request($request_url,$query_string,'raw');
+        $file = $this->backend_request('/attachment',$query_string,'raw');
         if (! $file) {
             throw new Exception('NO_ATTACHMENT');
         }
@@ -212,9 +209,7 @@ class Backend implements Serializable
     {
         global $App;
 
-        $request_url  = $this->base_url.'/license/';
-
-        $data = $this->backend_request($request_url);
+        $data = $this->backend_request('/license');
 
         if (! $data) {
             $App->log('[Backend/fetchLicense] No valid License found');
@@ -245,7 +240,6 @@ class Backend implements Serializable
         }
 
         $query = $Query->getQuery();
-        $request_url  = $this->base_url.'/search/';
         @list($archive,$scid) = preg_split('/\/+(?=[^\/]+$)/',$cidstring);  // scid: optional extension of name
         $query_string = 'archive='.$archive .
                  '&filterQuery='.$this->filter .
@@ -259,7 +253,7 @@ class Backend implements Serializable
         $App->log("Query string: $query",3,'Backend');
         $App->log("Filter string: $this->filter",4,'Backend');
 
-        $resultList = $this->backend_request($request_url,$query_string);
+        $resultList = $this->backend_request('/search',$query_string);
 
         if (! preg_match('/^LICENSE_VALID/',$resultList['licenseValid'])) {
             if ($App->getConfig('USERPERMISSONS','ENABLED') != 'DISABLED') {
@@ -277,16 +271,18 @@ class Backend implements Serializable
     /**
      * Backend request with fallback
      *
-     * @param string $request_url
+     * @param string $endpoint
      * @param string $query=false
      * @param string $format=''
      * @return array
      */
-    function backend_request($request_url,$query_string=false,$format='')
+    function backend_request($endpoint,$query_string=false,$format='')
     {
         global $App;
         $maildata = '';
 
+        $request_url  = $this->base_url.$endpoint.'/';
+
         try {
             $maildata = $this->_curl_query($request_url,$query_string,$format);
         }
@@ -295,7 +291,7 @@ class Backend implements Serializable
             if ($error_msg == 'ERR_REST_404') {
                 $base_url_fallback = $App->getConfig('BASE_URL_FALLBACK');
                 if ($base_url_fallback) {
-                    $fallback_url = rtrim($base_url_fallback,'/').'/mail/';
+                    $fallback_url = rtrim($base_url_fallback,'/').$endpoint.'/';
                     $App->log('Try to fetch from fallback backend: '.$fallback_url,2,'Backend');
                     $maildata = $this->_curl_query($fallback_url,$query_string,$format);
                 }
@@ -334,16 +330,35 @@ class Backend implements Serializable
                 throw new Exception('ERR_INTERN');
             }
         }
+
         $curl =& $this->_curl;
 
+
+        $rest_user = $this->rest_user;
+        $rest_pass = $this->rest_pass; 
+        $http_header = array('Expect:');
+
+        $url_parts = parse_url($request_url);
+        if (array_key_exists('user',$url_parts) && array_key_exists('pass',$url_parts)) {
+            if (preg_match('/^Bearer$/',$url_parts['user'])) {        // set Bearer token
+                //array_push($http_header,'Authorization: Bearer '.$this->gen_jwt($url_parts['pass']));  // gen_jwt() not implemented
+                $App->log('WARNING: JWT token handling not implemented yet',0,'Backend');
+            }
+            else {
+                $rest_user = $url_parts['user'];
+                $rest_user = $url_parts['user'];
+                array_push($http_header,'Authorization: Basic '.base64_encode($rest_user.':'.$rest_pass));
+            }
+        }
+        curl_setopt($curl, CURLOPT_USERPWD, $rest_user.':'.$rest_pass); 
+
         curl_setopt($curl, CURLOPT_URL, $request_url);
         curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
         curl_setopt($curl, CURLOPT_HEADER, 1);
         curl_setopt($curl, CURLOPT_POST, 1);
         curl_setopt($curl, CURLOPT_POSTFIELDS, $query);
         // suppress using of 100-Continue requests
-        curl_setopt($curl, CURLOPT_HTTPHEADER,array("Expect:"));
-        curl_setopt($curl, CURLOPT_USERPWD, $this->rest_user.':'.$this->rest_pass); 
+        curl_setopt($curl, CURLOPT_HTTPHEADER,$http_header);
         if ($cookie_file) {
             curl_setopt($curl, CURLOPT_COOKIEJAR, $cookie_file);
             curl_setopt($curl, CURLOPT_COOKIEFILE, $cookie_file);
@@ -417,8 +432,7 @@ class Backend implements Serializable
 
     function destroy_bennorest_session()
     {
-        $request_url = $this->base_url.'/logout/';
-        $this->backend_request($request_url);
+        $this->backend_request('/logout');
     }
 
 }
